@@ -160,8 +160,12 @@ def build_android_bundle(app_path):
     _align_manifest_package(Path(android_dir))
     _fix_manifest_provider_authorities(Path(android_dir))
 
-    # Ensure app icon is copied from config location if available
+    # IMPORTANT: Ensure app icon is processed AFTER Capacitor sync (which overwrites icons)
     _ensure_app_icon(Path(android_dir))
+    
+    # Force another clean after icon updates to clear any cached artifacts
+    print("🧹 Clearing Gradle build cache after icon updates...")
+    force_clean_gradle(android_dir)
 
     # Ensure release signing is configured (writes signing.properties; injects Gradle config)
     _ensure_release_signing(Path(android_dir))
@@ -286,7 +290,9 @@ def _align_manifest_package(android_dir: Path) -> None:
         print(f"🏷️ Manifest package aligned to: {target_app_id}")
 
 def _ensure_app_icon(android_dir: Path) -> None:
-    """Copy appIcon.png from config locations and generate Android mipmap resources."""
+    """Copy appIcon.png and splash screen from config locations and generate Android resources."""
+    print("🔍 Looking for app icon and splash screen...")
+    
     # Look for appIcon.png in known config locations
     icon_candidates = [
         os.environ.get("AIROBO_APP_ICON_PATH"),
@@ -295,51 +301,241 @@ def _ensure_app_icon(android_dir: Path) -> None:
         os.path.expanduser("~/airoboConfigs/appIcon.png"),
     ]
     
+    # Look for splash screen in same locations
+    splash_candidates = [
+        os.environ.get("AIROBO_SPLASH_PATH"),
+        r"C:\airoboConfigs\splash.png",
+        r"C:\airobo\splash.png",
+        os.path.expanduser("~/airoboConfigs/splash.png"),
+    ]
+    
+    # Debug: show what we're checking
+    print("🔍 Checking for app icon:")
+    for i, candidate in enumerate(icon_candidates):
+        if candidate:
+            exists = os.path.isfile(candidate)
+            print(f"   {i+1}. {candidate} {'✅' if exists else '❌'}")
+    
+    print("🔍 Checking for splash screen:")
+    for i, candidate in enumerate(splash_candidates):
+        if candidate:
+            exists = os.path.isfile(candidate)
+            print(f"   {i+1}. {candidate} {'✅' if exists else '❌'}")
+    
+    # Find source files
     source_icon = None
     for candidate in icon_candidates:
         if candidate and os.path.isfile(candidate):
             source_icon = Path(candidate)
             break
     
+    source_splash = None
+    for candidate in splash_candidates:
+        if candidate and os.path.isfile(candidate):
+            source_splash = Path(candidate)
+            break
+    
     if not source_icon:
-        print("ℹ️ No appIcon.png found in config locations. Using default icon.")
+        print("❌ No appIcon.png found in config locations. Using default icon.")
         return
     
-    # Android mipmap density folders and target sizes
+    print(f"✅ Found app icon: {source_icon}")
+    if source_splash:
+        print(f"✅ Found splash screen: {source_splash}")
+    
+    # Get the app cache root to also update web icons that Capacitor uses
+    app_cache_root = android_dir.parent
+    web_public_dir = app_cache_root / "public"
+    
+    # Android mipmap density folders and target sizes - HIGHER RES for better quality
     densities = {
-        "mipmap-mdpi": 48,
-        "mipmap-hdpi": 72,
-        "mipmap-xhdpi": 96,
-        "mipmap-xxhdpi": 144,
-        "mipmap-xxxhdpi": 192,
+        "mipmap-mdpi": 64,      # Was 48, now higher base
+        "mipmap-hdpi": 96,      # Was 72 
+        "mipmap-xhdpi": 128,    # Was 96
+        "mipmap-xxhdpi": 192,   # Was 144
+        "mipmap-xxxhdpi": 256,  # Was 192 - this is what most modern phones use!
     }
     
     res_dir = android_dir / "app" / "src" / "main" / "res"
+    print(f"📁 Target res directory: {res_dir}")
+    print(f"🌐 Web public directory: {web_public_dir}")
     
     try:
         from PIL import Image
+        print("📦 Pillow loaded successfully")
+        
         # Load source image
         with Image.open(source_icon) as img:
+            print(f"🖼️ Source image: {img.size[0]}x{img.size[1]} pixels, mode: {img.mode}")
+            
             # Convert to RGBA if needed for transparency support
             if img.mode != 'RGBA':
                 img = img.convert('RGBA')
+                print("🔄 Converted to RGBA mode")
             
-            # Generate icons for each density
+            # FIRST: Replace web icons that Capacitor might use as source
+            web_icons_updated = 0
+            if web_public_dir.exists():
+                # Replace favicon.ico (convert to ICO format)
+                favicon_path = web_public_dir / "favicon.ico"
+                if favicon_path.exists():
+                    # Create a 32x32 version for favicon
+                    favicon_img = img.resize((32, 32), Image.Resampling.LANCZOS)
+                    favicon_img.save(favicon_path, "ICO", sizes=[(32, 32)])
+                    print(f"🌐 Updated favicon.ico: {favicon_path}")
+                    web_icons_updated += 1
+                
+                # Also create icon.png in public directory (common Capacitor source)
+                icon_png_path = web_public_dir / "icon.png"
+                img.save(icon_png_path, "PNG", optimize=True)
+                print(f"🌐 Created icon.png: {icon_png_path}")
+                web_icons_updated += 1
+            
+            # ALSO: Update the Android assets/public directory (where Capacitor copies web assets)
+            android_assets_public = android_dir / "app" / "src" / "main" / "assets" / "public"
+            if android_assets_public.exists():
+                favicon_assets_path = android_assets_public / "favicon.ico"
+                if favicon_assets_path.exists():
+                    favicon_img = img.resize((32, 32), Image.Resampling.LANCZOS)
+                    favicon_img.save(favicon_assets_path, "ICO", sizes=[(32, 32)])
+                    print(f"🔧 Updated Android assets favicon.ico: {favicon_assets_path}")
+                    web_icons_updated += 1
+                
+                # Also update icon.png in assets if it exists or create it
+                icon_assets_path = android_assets_public / "icon.png"
+                img.save(icon_assets_path, "PNG", optimize=True)
+                print(f"🔧 Updated Android assets icon.png: {icon_assets_path}")
+                web_icons_updated += 1
+            
+            # THEN: Generate Android mipmap icons
+            icons_created = 0
             for density, size in densities.items():
                 density_dir = res_dir / density
                 density_dir.mkdir(parents=True, exist_ok=True)
                 
-                # Resize and save
-                resized = img.resize((size, size), Image.Resampling.LANCZOS)
-                output_path = density_dir / "ic_launcher.png"
-                resized.save(output_path, "PNG", optimize=True)
+                # For adaptive icons, we need larger foreground images (108dp safe area)
+                # The visible area is ~72dp, but we need 108dp for the full adaptive icon
+                adaptive_size = int(size * 1.5)  # 1.5x for 108dp vs 72dp
                 
-                # Also create round icon variant
+                # Create standard size for regular icons
+                resized = img.resize((size, size), Image.Resampling.LANCZOS)
+                
+                # Create larger size for adaptive foreground (better quality)
+                adaptive_resized = img.resize((adaptive_size, adaptive_size), Image.Resampling.LANCZOS)
+                
+                # Regular launcher icons
+                output_path = density_dir / "ic_launcher.png"
+                resized.save(output_path, "PNG", optimize=False, compress_level=1)  # Less compression for better quality
+                
+                # Round icon variant
                 round_output = density_dir / "ic_launcher_round.png"
-                resized.save(round_output, "PNG", optimize=True)
+                resized.save(round_output, "PNG", optimize=False, compress_level=1)
+                
+                # CRITICAL: Adaptive icon foreground - use larger size for better quality
+                foreground_output = density_dir / "ic_launcher_foreground.png"
+                adaptive_resized.save(foreground_output, "PNG", optimize=False, compress_level=1)
+                
+                print(f"   📱 {density}: {size}x{size} -> {output_path}")
+                print(f"      + foreground: {adaptive_size}x{adaptive_size} -> {foreground_output}")
+                icons_created += 3  # launcher + round + foreground
+            
+            # SPLASH SCREENS: Replace all splash screens if splash image is provided
+            if source_splash:
+                print("🎨 Updating splash screens with proper densities...")
+                splash_files_updated = 0
+                
+                # Load splash image
+                with Image.open(source_splash) as splash_img:
+                    print(f"   📏 Source splash: {splash_img.size[0]}x{splash_img.size[1]}")
+                    
+                    # Standard splash screen sizes for different densities
+                    splash_densities = {
+                        "drawable-mdpi": (320, 480),       # ~160dpi
+                        "drawable-hdpi": (480, 720),       # ~240dpi  
+                        "drawable-xhdpi": (720, 1280),     # ~320dpi
+                        "drawable-xxhdpi": (1080, 1920),   # ~480dpi - most common
+                        "drawable-xxxhdpi": (1440, 2560),  # ~640dpi - highest res
+                    }
+                    
+                    # Also handle landscape orientations
+                    splash_densities_land = {
+                        "drawable-land-mdpi": (480, 320),
+                        "drawable-land-hdpi": (720, 480),
+                        "drawable-land-xhdpi": (1280, 720),
+                        "drawable-land-xxhdpi": (1920, 1080),
+                        "drawable-land-xxxhdpi": (2560, 1440),
+                    }
+                    
+                    # Combine both orientations
+                    all_splash_densities = {**splash_densities, **splash_densities_land}
+                    
+                    # Generate splash screens for each density
+                    for density_name, (width, height) in all_splash_densities.items():
+                        density_dir = res_dir / density_name
+                        density_dir.mkdir(parents=True, exist_ok=True)
+                        
+                        # Resize maintaining aspect ratio, center on colored background
+                        splash_resized = splash_img.resize((width, height), Image.Resampling.LANCZOS)
+                        
+                        splash_output = density_dir / "splash.png"
+                        splash_resized.save(splash_output, "PNG", optimize=False, compress_level=1)
+                        print(f"   🖼️ {density_name}: {width}x{height} -> {splash_output}")
+                        splash_files_updated += 1
+                    
+                    # Also find and replace any existing splash files with our custom one
+                    for splash_file in res_dir.rglob("*splash*"):
+                        if splash_file.is_file() and splash_file.suffix.lower() in ('.png', '.jpg', '.jpeg'):
+                            if splash_file.parent.name not in all_splash_densities:
+                                # This is an existing splash file, replace it with our custom splash
+                                default_splash = splash_img.resize((1080, 1920), Image.Resampling.LANCZOS)
+                                default_splash.save(splash_file, "PNG", optimize=False, compress_level=1)
+                                print(f"   🔄 Replaced existing: {splash_file.relative_to(res_dir)}")
+                                splash_files_updated += 1
+                    
+                    # CRITICAL: Update styles.xml to ensure splash screen uses our image, not app icon
+                    styles_file = res_dir / "values" / "styles.xml"
+                    if styles_file.exists():
+                        print("🎨 Updating styles.xml to prevent app icon fallback...")
+                        try:
+                            styles_content = styles_file.read_text(encoding='utf-8')
+                            
+                            # Replace any references to app icon in splash screen styles
+                            # Look for windowSplashscreenContent that might reference the app icon
+                            updated_styles = styles_content.replace(
+                                '@mipmap/ic_launcher', '@drawable/splash'
+                            ).replace(
+                                '@mipmap/ic_launcher_foreground', '@drawable/splash'  
+                            ).replace(
+                                'ic_launcher', 'splash'
+                            )
+                            
+                            if updated_styles != styles_content:
+                                styles_file.write_text(updated_styles, encoding='utf-8')
+                                print("   ✅ Updated styles.xml to use splash drawable instead of app icon")
+                            else:
+                                print("   ℹ️ styles.xml already configured correctly")
+                                
+                        except Exception as e:
+                            print(f"   ⚠️ Could not update styles.xml: {e}")
+                
+                print(f"🎨 Generated {splash_files_updated} splash screen files across multiple densities")
+                print("🎯 Splash screen should now display your custom image, not the app icon")
+            else:
+                print("ℹ️ No splash screen found to process")
             
             print(f"🎨 App icon processed from: {source_icon}")
-            print(f"   Generated {len(densities)} density variants")
+            print(f"   Generated {icons_created} icon files across {len(densities)} densities")
+            
+            # Verify files were actually created
+            print("🔍 Verifying created icon files:")
+            for density in densities.keys():
+                density_dir = res_dir / density
+                ic_launcher = density_dir / "ic_launcher.png"
+                ic_launcher_round = density_dir / "ic_launcher_round.png"
+                ic_launcher_foreground = density_dir / "ic_launcher_foreground.png"
+                print(f"   {density}/ic_launcher.png: {'✅' if ic_launcher.exists() else '❌'}")
+                print(f"   {density}/ic_launcher_round.png: {'✅' if ic_launcher_round.exists() else '❌'}")
+                print(f"   {density}/ic_launcher_foreground.png: {'✅' if ic_launcher_foreground.exists() else '❌'}")
             
     except ImportError:
         print("⚠️ Pillow not installed. Installing for icon processing...")
@@ -354,7 +550,9 @@ def _ensure_app_icon(android_dir: Path) -> None:
         except subprocess.CalledProcessError:
             print("❌ Failed to install Pillow. Using default app icon.")
     except Exception as e:
-        print(f"⚠️ Icon processing failed: {e}. Using default icon.")
+        print(f"❌ Icon processing failed: {e}. Using default icon.")
+        import traceback
+        traceback.print_exc()
 
 def update_android_version(app_path):
     """Update Android version codes before building using git commit count"""
